@@ -2,7 +2,7 @@
 #'
 #' @description The function calculates MAGE values and can optionally return a plot of the glucose trace.
 #'
-#' @param data Data Frame object with column names "id", "time", and "gl" OR numeric vector of glucose values (numeric vector allowed for version \code{'naive'} only).
+#' @param data DataFrame object with column names "id", "time", and "gl" OR numeric vector of glucose values.
 #'
 #' @param version Either \code{'ma'} or \code{'naive'}. Chooses which version of the MAGE algorithm to use. \code{'ma'} algorithm is more accurate, and is the default. Earlier versions of iglu package (<=2.0.0) used \code{'naive'}.
 #'
@@ -18,7 +18,7 @@
 #' be returned with one plot per subject.
 #' @export
 #'
-#' @details If version \code{'ma'} is selected, the function computationally emulates the manual method for calculating the mean amplitude of glycemic excursions (MAGE) first suggested in Mean Amplitude of Glycemic Excursions, a Measure of Diabetic Instability, (Service, 1970). For this version, glucose values will be interpolated over a uniform time grid prior to calculation.
+#' @details If version \code{'ma'} is selected, the function computationally emulates the manual method for calculating the mean amplitude of glycemic excursions (MAGE) first suggested in "Mean Amplitude of Glycemic Excursions, a Measure of Diabetic Instability", (Service, 1970). For this version, glucose values will be interpolated over a uniform time grid prior to calculation.
 #'
 #' \code{'ma'} is a more accurate algorithm that uses the crosses of a short and long moving average to identify intervals where a peak/nadir might exist. Then, the height from one peak/nadir to the next nadir/peak is calculated from the *original* (not moving average) glucose values.
 #'
@@ -33,8 +33,6 @@
 #' data(example_data_5_subject)
 #' mage(example_data_5_subject, version = 'ma')
 
-
-
 mage <- function(data, version = c('ma', 'naive'), sd_multiplier = 1,
                  short_ma = 5, long_ma = 32, type = c('auto', 'plus', 'minus'),
                  plot = FALSE, dt0 = NULL, inter_gap = 45, tz = "",
@@ -60,7 +58,7 @@ mage_ma <- function(data, short_ma = 5, long_ma = 32, type = c('auto', 'plus', '
   rm(list = c("id", ".", "MAGE"))
 
   data = check_data_columns(data)
-  is_vector = attr(data, "is_vector")
+  is_vector = attr(data, "is_vector") # TODO: is this check really necessary? when does this return true?
 
   out <- data %>%
     dplyr::filter(!is.na(gl)) %>%
@@ -96,14 +94,14 @@ mage_sd <- function(data, sd_multiplier = 1){
     dplyr::filter(!is.na(gl)) %>%
     dplyr::group_by(id) %>%
     dplyr::mutate(abs_diff_mean = abs(gl - mean(gl, na.rm = TRUE))) %>%
-    dplyr::summarise(
+    dplyr::reframe(
       MAGE = mean(
         abs_diff_mean[abs_diff_mean > (sd_multiplier * sd(gl, na.rm = TRUE))],
         na.rm = TRUE)
     )
-  #if (is_vector) {
-  #  out$id = NULL
-  #}
+  if (is_vector) {
+   out$id = NULL
+  }
   return(out)
 
 }
